==> kmud-0.5.tar.gz: kmud-0.5/kmud/ansi.h <==
/***************************************************************************
                          ansi.h
                      -------------------
    description          :
    begin                : Fri Sep 15 2000
    copyright            : (C) 2000 by Andre Alexander Bell
    email                : andre.bell@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#ifndef ANSI_H
#define ANSI_H

#define ANSICOLOR_COUNT 16

#define BLACK 0
#define DARK_RED 1
#define DARK_GREEN 2
#define DARK_YELLOW 3
#define DARK_BLUE 4
#define DARK_MAGENTA 5
#define DARK_CYAN 6
#define DARK_WHITE 7
#define GRAY 8
#define LIGHT_RED 9
#define LIGHT_GREEN 10
#define LIGHT_YELLOW 11
#define LIGHT_BLUE 12
#define LIGHT_MAGENTA 13
#define LIGHT_CYAN 14
#define LIGHT_WHITE 15

#define BGCOLOR_COUNT 8

#define BG_BLACK 0
#define BG_RED 1
#define BG_GREEN 2
#define BG_YELLOW 3
#define BG_BLUE 4
#define BG_MAGENTA 5
#define BG_CYAN 6
#define BG_WHITE 7

const QString ANSICOLOR_NAME[ANSICOLOR_COUNT]=
	{
		"ANSI_Black",
		"ANSI_DarkRed",
		"ANSI_DarkGreen",
		"ANSI_DarkYellow",
		"ANSI_DarkBlue",
		"ANSI_DarkMagenta",
		"ANSI_DarkCyan",
		"ANSI_DarkWhite",
		"ANSI_Gray",
		"ANSI_LightRed",
		"ANSI_LightGreen",
		"ANSI_LightYellow",
		"ANSI_LightBlue",
		"ANSI_LightMagenta",
		"ANSI_LightCyan",
		"ANSI_LightWhite",
	};
	
const QString BGCOLOR_NAME[BGCOLOR_COUNT]=
	{
		"BG_Black",
		"BG_Red",
		"BG_Green",
		"BG_Yellow",
		"BG_Blue",
		"BG_Magenta",
		"BG_Cyan",
		"BG_White"
	};

#endif

==> kmud-1.0.tar.gz: kmud-1.0/kmud/ansi.h <==
/***************************************************************************
                          ansi.h
                      -------------------
    description          :
    begin                : Fri Sep 15 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#ifndef ANSI_H
#define ANSI_H

#define ANSICOLOR_COUNT 16

#define BLACK 0
#define DARK_RED 1
#define DARK_GREEN 2
#define DARK_YELLOW 3
#define DARK_BLUE 4
#define DARK_MAGENTA 5
#define DARK_CYAN 6
#define DARK_WHITE 7
#define GRAY 8
#define LIGHT_RED 9
#define LIGHT_GREEN 10
#define LIGHT_YELLOW 11
#define LIGHT_BLUE 12
#define LIGHT_MAGENTA 13
#define LIGHT_CYAN 14
#define LIGHT_WHITE 15

#define BGCOLOR_COUNT 8

#define BG_BLACK 0
#define BG_RED 1
#define BG_GREEN 2
#define BG_YELLOW 3
#define BG_BLUE 4
#define BG_MAGENTA 5
#define BG_CYAN 6
#define BG_WHITE 7

const QString ANSICOLOR_NAME[ANSICOLOR_COUNT]=
	{
		"ANSI_Black",
		"ANSI_DarkRed",
		"ANSI_DarkGreen",
		"ANSI_DarkYellow",
		"ANSI_DarkBlue",
		"ANSI_DarkMagenta",
		"ANSI_DarkCyan",
		"ANSI_DarkWhite",
		"ANSI_Gray",
		"ANSI_LightRed",
		"ANSI_LightGreen",
		"ANSI_LightYellow",
		"ANSI_LightBlue",
		"ANSI_LightMagenta",
		"ANSI_LightCyan",
		"ANSI_LightWhite",
	};
	
const QString BGCOLOR_NAME[BGCOLOR_COUNT]=
	{
		"BG_Black",
		"BG_Red",
		"BG_Green",
		"BG_Yellow",
		"BG_Blue",
		"BG_Magenta",
		"BG_Cyan",
		"BG_White"
	};

#endif
